==> pdfpug-0.2.0-py3-none-any.whl: pdfpug/modules/orderedlist.py <==
#  MIT License
#
#  Copyright (C) 2019 Nekhelesh Ramananthan
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
#  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
#  PARTICULAR PURPOSE AND  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
#  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
#  AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
#  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

from typing import List

from pdfpug.common import Orientation, Size, ListType
from pdfpug.modules import BaseList


class OrderedList(BaseList):
    """
    OrderedList is used to represent an *ordered* list of items in numerical order
    format.

    :param List items: List items
    :param Orientation orientation: Orientation of list (defaults to
        ``Orientation.vertical``)
    :param Size size: Size (defaults to ``Size.small``)

    Instantiating a list is as simple as the following,

    >>> from pdfpug import OrderedList
    >>> chapters = OrderedList(['Introduction', {'Chapter 1': ['Header 1', 'Header 2']}])
    """

    def __init__(self, items: List, **kwargs) -> None:
        super().__init__(
            items,
            ListType.ordered,
            kwargs.get("orientation", Orientation.vertical),
            kwargs.get("size", Size.small),
        )

==> pdfpug-0.3.0-py3-none-any.whl: pdfpug/modules/orderedlist.py <==
#  MIT License
#
#  Copyright (C) 2019 Nekhelesh Ramananthan
#
#  Permission is hereby granted, free of charge, to any person obtaining a copy
#  of this software and associated documentation files (the "Software"), to deal
#  in the Software without restriction, including without limitation the rights
#  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
#  copies of the Software, and to permit persons to whom the Software is
#  furnished to do so, subject to the following conditions:
#
#  The above copyright notice and this permission notice shall be included in all
#  copies or substantial portions of the Software.
#
#  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED,
#  INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A
#  PARTICULAR PURPOSE AND  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR
#  COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
#  AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
#  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

from typing import List

from pdfpug.common import Orientation, Size, ListType
from pdfpug.modules import BaseList


class OrderedList(BaseList):
    """
    OrderedList is used to represent an *ordered* list of items in numerical order
    format.

    :param List items: List items
    :param Orientation orientation: Orientation of list (defaults to
        ``Orientation.vertical``)
    :param Size size: Size (defaults to ``Size.small``)

    Instantiating a list is as simple as the following,

    >>> from pdfpug.modules import OrderedList
    >>> chapters = OrderedList(['Introduction', {'Chapter 1': ['Header 1', 'Header 2']}])
    """

    def __init__(self, items: List, **kwargs) -> None:
        super().__init__(
            items,
            ListType.ordered,
            kwargs.get("orientation", Orientation.vertical),
            kwargs.get("size", Size.small),
        )
